@@ -91,12 +91,19 @@ ergm.MEM_boot<-function(model,
   if(is.null(var2)){
 
 
+    if(length(var1)>1){
+    MEM.fun<-function(theta){
+
+      ME.ergm<-sapply(names(theta),function(x)
+        (p*(1-p)*sum(theta[var1])))
+      mean(ME.ergm,na.rm = TRUE)}
+    }else{
     MEM.fun<-function(theta){
 
       ME.ergm<-sapply(names(theta),function(x)
         (p*(1-p)*theta[var1]))
       mean(ME.ergm,na.rm = TRUE)}
-
+    }
 
     MEM<-MEM.fun(theta)
     MEM_boots<-apply(theta_boot,1,FUN=MEM.fun)
@@ -107,7 +114,7 @@ ergm.MEM_boot<-function(model,
 
     MEM<-matrix(c(MEM,MEM.se,MEM.z,P.MEM),nrow=1,ncol=4)
     colnames(MEM)<-c("MEM","Bootstrap SE","Z","P")
-    rownames(MEM)<-var1
+    rownames(MEM)<-ifelse(length(var1),paste(var1,collapse="+"),var1)
     MEM<-signif(MEM,digits=5)
 
     if(return.dydx==TRUE){
